LineWidth

Struct LineWidth 

pub struct LineWidth(/* private fields */);
Maximum line width for text wrapping (must be at least 8).

Implementations

Source

impl LineWidth

pub const MIN: usize = 8

Minimum allowed line width.

pub const RECOMMENDED_MIN: usize = 40

Recommended minimum line width.

pub fn new(value: usize) -> Result<Self, String>

Create a new LineWidth.

Returns an error if the value is less than 8.

pub fn get(self) -> usize

Get the inner value.

Check if the line width is below the recommended minimum.