pub struct LineWidth(/* private fields */);Expand description
Maximum line width for text wrapping (must be at least 8).
Implementations
Sourceimpl LineWidth
impl LineWidth
Sourcepub const RECOMMENDED_MIN: usize = 40
pub const RECOMMENDED_MIN: usize = 40
Recommended minimum line width.
Sourcepub fn new(value: usize) -> Result<Self, String>
pub fn new(value: usize) -> Result<Self, String>
Create a new LineWidth.
Returns an error if the value is less than 8.
Sourcepub fn is_below_recommended(self) -> bool
pub fn is_below_recommended(self) -> bool
Check if the line width is below the recommended minimum.